@@ -1,10 +1,10 @@
 /* Test of filtering of data through a subprocess.
-   Copyright (C) 2009-2016 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
    Written by Bruno Haible <haible@clisp.cons.org>, 2009.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 
@@ -22,7 +22,6 @@
 #include "binary-io.h"
 #include "c-ctype.h"
 #include "read-file.h"
-#include "progname.h"
 #include "macros.h"
 
 
@@ -97,20 +96,18 @@ main (int argc, char *argv[])
   size_t input_size;
   char *input;
 
-  set_program_name (argv[0]);
-
   ASSERT (argc == 3);
 
   tr_program = argv[1];
 
   /* Read some text from a file.  */
   input_filename = argv[2];
-  input = read_binary_file (input_filename, &input_size);
+  input = read_file (input_filename, RF_BINARY, &input_size);
   ASSERT (input != NULL);
 
   /* Convert it to uppercase, line by line.  */
   {
-    const char *argv[4];
+    const char *tr_argv[4];
     struct locals l;
     int result;
 
@@ -119,12 +116,12 @@ main (int argc, char *argv[])
     l.nwritten = 0;
     l.nread = 0;
 
-    argv[0] = tr_program;
-    argv[1] = "abcdefghijklmnopqrstuvwxyz";
-    argv[2] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
-    argv[3] = NULL;
+    tr_argv[0] = tr_program;
+    tr_argv[1] = "abcdefghijklmnopqrstuvwxyz";
+    tr_argv[2] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+    tr_argv[3] = NULL;
 
-    result = pipe_filter_ii_execute ("tr", tr_program, argv, false, true,
+    result = pipe_filter_ii_execute ("tr", tr_program, tr_argv, false, true,
                                      prepare_write, done_write,
                                      prepare_read, done_read,
                                      &l);
@@ -133,5 +130,7 @@ main (int argc, char *argv[])
     ASSERT (l.nread == input_size);
   }
 
+  free (input);
+
   return 0;
 }
